logic2: Function to implement second logical reasoning to update...

Description Usage Arguments Value

Description

This function looks for locations that a number cannot go, and will update the 9x9x9 logical array from NA to FALSE.

Usage

1
logic2(puzList)

Arguments

puzList

a sudokuPuzzle object which contains a 9x9 matrix representation of a sudoku puzzle as the first list element and a 9x9x9 logical array representing the solutions of the sudoku puzzle

Value

This function looks within each of the smaller 9 3x3 boxes within the sudoku puzzle to search if there is a number that must go in a particular row or column within the 3x3 box. If such a number is found this means that this number cannot go in any part of the row or column that is not within the given 3x3 box. Therefore, the function will update the corresponding row or column in the array to reflect this.


JamesCuster/sudokusolvr documentation built on June 4, 2019, 7:46 a.m.