Description Usage Arguments Value
Takes a 9x9 matrix that represents a sudoku puzzle and returns the puzzle solved.
1 | solver(puz)
|
puz |
9x9 matrix representation of a sudoku puzzle. Cells of the sudoku
puzzle which are not filled in should be represented by |
Takes as input a 9x9 representation of a sudoku puzzle and finds and
returns its solution. This function utilizes the functions initArray
as well as logic1, logic2, upArray recursively in
order to find the solution for the puzzle
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.