Description Usage Arguments Value
The function sudokuPuzzle creates a sudoku puzzle object, which is a
list that contains the sudoku puzzle as the first list item and a 9x9x9
logical array which is used to represent and find the solutions to the puzzle
1 | sudokuPuzzle(puz)
|
puz |
a 9x9 matrix representation of a sudoku puzzle. Puzzle cells which
do not contain a number should be coded as |
A sudokuPuzzle object is a list object with two elements. The first
element is a 9x9 matrix representation of a sudoku puzzle. This is the same
as the input puz. The second element is a 9x9x9 logical array which
stores information about what values can and cannot go into specific cells
of the sudoku puzzle. The array is created using initArray.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.