Description Usage Arguments Value
This function searches over the i rows and j columns of each kth dimension of
the 9x9x9 logical array. It searches for rows and columns where there is only
one NA value. If a row or column that meets this criteria is found the
function returns the [i, j, k] indicies where it occurs.
1 | logic1(puzList)
|
puzList |
a |
The function searches the logical array of the sudokuPuzzle object
for new solutions. If a solution is found, the function returns the
[i, j, k] index where it occurs. If no new solution is found
NULL is returned. This function is meant to be used recursively
inside of the solver function in conjunction with upPuz which
takes the output of logic1 as input to update the 9x9 puzzle matrix
and the 9x9x9 logical array of the sudokuPuzzle object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.