Description Usage Arguments Value
This function looks for locations that a number cannot go, and will update
the 9x9x9 logical array from NA to FALSE.
1 | logic2(puzList)
|
puzList |
a |
This function looks within each of the smaller 9 3x3 boxes within the sudoku puzzle to search if there is a number that must go in a particular row or column within the 3x3 box. If such a number is found this means that this number cannot go in any part of the row or column that is not within the given 3x3 box. Therefore, the function will update the corresponding row or column in the array to reflect this.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.