Description Usage Arguments Value Examples
This function takes a puzzle array and a solution for the puzzle given as an
[i, j, k] index and update the array given the provided solution.
1 | upArray(puzArr, i, j, k)
|
puzArr |
9x9x9 array corresponding to the sudoku puzzle to be solved. |
i, j |
integer between 1 and 9 referrencing the |
k |
integer between 1 and 9. Represents the value that goes in the
|
Returns an updated puzzle array. Given that k goes in the [i,
j] element of the puzzle matrix, the puzzle array is updated accordingly
by placing TRUE/FALSE values in the appropriate places in the
puzzle array.
Function is used within initArray to initialize the puzzle array
given the starting values of the sudoku puzzle.
1 | ## Not run: upArray(b, 1, 1, 1)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.